@@ -12,8 +12,8 @@
 ***************************************************************************
 */
 
-#ifndef _DLRNUMERIC_BSPLINE_H_
-#define _DLRNUMERIC_BSPLINE_H_
+#ifndef DLR_NUMERIC_BSPLINE_H
+#define DLR_NUMERIC_BSPLINE_H
 
 #include <vector>
 #include <dlrNumeric/array1D.h>
@@ -28,13 +28,21 @@ namespace dlr {
      ** Warning: This class is very new, and its test suite is still
      ** incomplete.  It may contain bugs.
      **
-     ** This class templated implements a B-spline of arbitrary order.
+     ** This class template implements a B-spline of arbitrary order.
      ** It is templated on control point type so that you can, for
-     ** example, create a 2D spline by specifying control points of
-     ** type Vector2D.  This class supports both periodic and
-     ** non-periodic splines, and supports uniform node spacing,
-     ** non-uniform node spacing, and multiple knots to allow corners
-     ** and discontinuities.
+     ** example, create a spline with 2D or 3D values by by specifying
+     ** control points of type Vector2D or Vector3D.  Note that the
+     ** splines represented by this class are all 1D in the sense that
+     ** you can represent them using a parametric function of one
+     ** parameter.  If you set the template parameter to be Vector2D,
+     ** then you wind up with a function that converts this 1D input
+     ** parameter into 2D output values.  If you want a spline that
+     ** has two input parameters, perhaps to represent a surface, then
+     ** you need to use the similar, but more restrictive, BSpline2D
+     ** class.  The BSpline class supports both periodic and
+     ** non-periodic splines, supports both uniform and non-uniform
+     ** node spacing, and supports multiple knots at each node to
+     ** allow corners and discontinuities.
      **/
     template <class Type>
     class BSpline {
@@ -113,8 +121,8 @@ namespace dlr {
       /** 
        * This member function sets the knot multiplicity at each node
        * of the spline.  Setting the knot multiplicity of a node to N
-       * will introduce, at that node, a discontinuity in the (order -
-       * N + 1)th derivative of the spline.  This means that a knot
+       * will introduce, at that node, a discontinuity in the ((order
+       * - N) + 1)th derivative of the spline.  This means that a knot
        * multipicity equal to the order of the spline will introduce a
        * "corner" (discontinuity in the 1st derivative) and a
        * multipicity equal to (order + 1) will introduce a break in
@@ -452,7 +460,8 @@ namespace dlr {
     {
       if(m_nodePositionArray.size() == 0) {
         DLR_THROW(StateException, "BSpline::getMaximumSValue()",
-                  "Node positions have not been set.");
+                  "Node positions have not been set.  You must first call"
+                  " setNumberOfNodes() or setNodePositions().");
       }
       return m_nodePositionArray[m_nodePositionArray.size() - 1];
     }
@@ -467,14 +476,15 @@ namespace dlr {
     {
       if(m_nodePositionArray.size() == 0) {
         DLR_THROW(StateException, "BSpline::getMinimumSValue()",
-                  "Node positions have not been set.");
+                  "Node positions have not been set.  You must first call"
+                  " setNumberOfNodes() or setNodePositions().");
       }
       return m_nodePositionArray[0];
     }
 
 
     // This member function sets the values of the control points of
-    // the spline.  If the spline is periodic, then the value of the
+    // the spline.
     template <class Type>
     void
     BSpline<Type>::
@@ -503,7 +513,10 @@ namespace dlr {
       }
       if(m_knotPositionArray.size() < m_nodePositionArray.size()) {
         DLR_THROW(StateException, "BSpline::setControlPoints()",
-                  "Knot positions have not been initialized.");
+                  "Knot positions have not been initialized.  You must first"
+                  " call setKnotMultiplicies(), or else call"
+                  " setNumberOfNodes() with argument setKnotMultipliciesFlag"
+                  " set to true.");
       }
       m_controlPoints = controlPoints;
       m_controlPointVectorArray = this->getControlPointVectors(
@@ -938,7 +951,7 @@ namespace dlr {
 
     
   } // namespace numeric
-  
+
 } // namespace dlr
 
-#endif /* #ifndef _DLRNUMERIC_BSPLINE_H_ */
+#endif /* #ifndef DLR_NUMERIC_BSPLINE_H */
